@@ -118,32 +118,40 @@ static inline llvm::Reloc::Model getRelocModel() {
 }
 #endif
 
-void printVersion() {
-  printf("LDC - the LLVM D compiler (%s):\n", global.ldc_version);
-  printf("  based on DMD %s and LLVM %s\n", global.version,
-         global.llvm_version);
+// This function exits the program.
+void printVersion(llvm::raw_ostream &OS) {
+  OS << "LDC - the LLVM D compiler (" << global.ldc_version << "):\n";
+  OS << "  based on DMD " << global.version << " and LLVM " << global.llvm_version << "\n";
 #if defined(__has_feature)
 #if __has_feature(address_sanitizer)
-  printf("  compiled with address sanitizer enabled\n");
+  OS << "  compiled with address sanitizer enabled\n";
 #endif
 #endif
-  printf("  Default target: %s\n", llvm::sys::getDefaultTargetTriple().c_str());
+  OS << "  Default target: " << llvm::sys::getDefaultTargetTriple() << "\n";
   std::string CPU = llvm::sys::getHostCPUName();
   if (CPU == "generic") {
     CPU = "(unknown)";
   }
-  printf("  Host CPU: %s\n", CPU.c_str());
-  printf("  http://dlang.org - http://wiki.dlang.org/LDC\n");
-  printf("\n");
+  OS << "  Host CPU: " << CPU << "\n";
+  OS << "  http://dlang.org - http://wiki.dlang.org/LDC\n";
+  OS << "\n";
 
   // Without explicitly flushing here, only the target list is visible when
   // redirecting stdout to a file.
-  fflush(stdout);
+  OS.flush();
 
   llvm::TargetRegistry::printRegisteredTargetsForVersion();
+
   exit(EXIT_SUCCESS);
 }
 
+// This function exits the program.
+void printVersionStdout() {
+  printVersion(llvm::outs());
+  assert(false);
+}
+
+
 // Helper function to handle -d-debug=* and -d-version=*
 static void processVersions(std::vector<std::string> &list, const char *type,
                             void (*setLevel)(unsigned),
@@ -334,7 +342,8 @@ static void parseCommandLine(int argc, char **argv, Strings &sourceFiles,
 
   final_args.insert(final_args.end(), &argv[1], &argv[argc]);
 
-  cl::SetVersionPrinter(&printVersion);
+  cl::SetVersionPrinter(&printVersionStdout);
+
   hideLLVMOptions();
   cl::ParseCommandLineOptions(final_args.size(),
                               const_cast<char **>(final_args.data()),
@@ -932,7 +941,7 @@ int main(int argc, char **argv) {
   llvm::sys::PrintStackTraceOnErrorSignal();
 #endif
 
-  exe_path::initialize(argv[0], reinterpret_cast<void *>(main));
+  exe_path::initialize(argv[0]);
 
   global.init();
   global.version = ldc::dmd_version;
